(****************************************************)
(* By : P. Gertzen                                  *)
(* ---------------                                  *)
(* If you'd like any modifications to this          *)
(* simple little component or any help with MS ISS  *)
(* Backend Dll's or Internet Client/Server Apps then*)
(* contact me at pgertzen@websa.com.                *)
(*                                                  *)
(* Check out our Delphi coded Internet server       *)
(* technology at:                                   *)
(* LiveAudit.com, FindProduct.com, Livesite.co.za   *)
(*                                                  *)
(* Check this component at work at LiveAudit.com    *)
(****************************************************)

unit wsaGraph;

interface

Uses Classes,ExtCtrls, StdCtrls,SysUtils, Graphics;

Type
  TGraphType = (BarGraph,LineGraph);

  TDataObject = Class(TObject)
  Private
    FValue : Real;
    FLabel : String;
  Public
    Constructor Create(Value : Real; PosLabel : String);
  End;

  TGauge = Class(TImage)
  Private
    FPercentage : Real;
    FGaugeColor : Integer;
    FBarColor : Integer;
    FOrientation : Integer;
  Public
    Procedure SetGauge(Percentage : Real);
  Published
    Property BarColor : Integer Read FBarColor Write FBarColor;
    Property GaugeColor : Integer Read FGaugecolor Write FGaugeColor;
    Property Orientation : Integer Read FOrientation Write FOrientation;
  End;

  TwsaGraph = Class(TImage)
  Private
    FLegend : TStringList;
    FGraphType : TGraphType;
    FHeader : String;
    FHeaderFontName : String;
    FYAxisFontName : String;
    FXAxisFontName : String;
    FPenColor : Integer;
    FFooter : String;
    FYHeader: String;
    FXHeader: String;
    FShowHorizLines : Boolean;
    FShowVertLines : Boolean;
    FDataList : TList;
    FDataObject : TDataObject;
    FHeaderFontSize : Integer;
    FXFontSize : Integer;
    FXFontColor : Integer;
    FYFontSize : Integer;
    FYFontColor : Integer;
    FHeaderFontColor : Integer;
    FLeftMargin,
    FRightMargin,
    FTopMargin,
    FBottomMargin : Integer;
    FFooterFontName : String;
    FFooterFontSize : Integer;
    FFooterFontColor : Integer;
    FLeftFontName : String;
    FLeftFontSize : Integer;
    FLeftFontColor : Integer;
    FLeftLabel : String;
    FIncValue : Real;
    FXFontName : String;
    FTicks : Integer;
    FMaxValue : Real;
    FGraphColor : Integer;
    FBackgroundColor : Integer;
    FLineWidth : Integer;
    Procedure CalcPeriods;
    Function GetNextColor(CurrentColor : Integer) : Integer;
    Function GetLegend(Index : Integer) : String;
    Procedure SetLegend(Index : Integer;Value : String);
  Public
    Constructor Create(AOwner : TComponent); override;
    Destructor Destroy; override;
    Procedure AddData(Series,X : Integer;Value : Real; PosLabel : String);
    Procedure PlotGraph;
    Procedure ClearGraph;
  Published
    Property LineWidth : Integer Read FLineWidth Write FLineWidth;
    Property Legend[Index : Integer] : String Read GetLegend Write SetLegend;
    Property PenColor : Integer Read FPenColor Write FPenColor;
    Property GraphType : TGraphType Read FGraphType Write FGraphType;
    Property BackgroundColor : Integer Read FBackgroundColor Write FBackgroundColor;
    Property HeaderFontName : String Read FHeaderFontName Write FHeaderFontName;
    Property HeaderFontSize : Integer Read FHeaderFontSize Write FHeaderFontSize;
    Property HeaderFontColor : Integer Read FHeaderFontColor Write FHeaderFontColor;
    Property FooterFontName : String Read FFooterFontName Write FFooterFontName;
    Property FooterFontSize : Integer Read FFooterFontSize Write FFooterFontSize;
    Property FooterFontColor : Integer Read FFooterFontColor Write FFooterFontColor;
    Property LeftFontName : String Read FLeftFontName Write FLeftFontName;
    Property LeftFontSize : Integer Read FLeftFontSize Write FLeftFontSize;
    Property LeftFontColor : Integer Read FLeftFontColor Write FLeftFontColor;
    Property XFontName : String Read FXFontName write FXFontName;
    Property XFontSize : Integer Read FXFontSize Write FXFontSize;
    Property YFontSize : Integer Read FYFontSize Write FYFontSize;
    Property XFontColor : Integer Read FXFontColor Write FXFontColor;
    Property YFontColor : Integer Read FYFontColor Write FYFontColor;
    Property YAxisFontName : String Read FYAxisFontName Write FYAxisFontName;
    Property XAxisFontName : String Read FXAxisFontName Write FXAxisFontName;
    Property Header : String Read FHeader Write FHeader;
    Property LeftLabel : String Read FLeftLabel Write FLeftLabel;
    Property Footer : String Read FFooter Write FFooter;
    Property YHeader: String Read FYHeader Write FYHeader;
    Property XHeader: String Read FXHeader Write FXHeader;
    Property ShowHorizLines : Boolean Read FShowHorizLines Write FShowHorizLines;
    Property ShowVertLines : Boolean Read FShowVertLines Write FShowVertLines;
    Property GraphColor : Integer Read FGraphcolor Write FGraphColor;
  End;

Procedure Register;

implementation

Uses Math, Windows;

Procedure TGauge.SetGauge(Percentage : Real);
Var XPos,YPos : Integer;
    Bitmap : Graphics.TBitmap;
    Src,Dest : TRect;
Begin
  Bitmap := Graphics.TBitmap.Create;
  Canvas.Brush.Color := GaugeColor;
  Canvas.Rectangle(0,0,Width,Height);
  Canvas.Brush.Color := BarColor;
  If Orientation = 0 Then
   Canvas.Rectangle(0,0,Round((Percentage/100)*Width),Height)
  Else
   Canvas.Rectangle(0,Height,Width,Height-Round((Percentage/100)*Height));
  Canvas.Brush.Color := clBlack;
  Canvas.Font.Color := clWhite;
  If Orientation = 0 Then
   Begin
     Canvas.Font.Size := Height Div 2;
     XPos := (Width Div 2) -
             (Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2);
     YPos := (Height Div 2) -
             (Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Left := (Width Div 2) -
                 (Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Top := (Height Div 2) -
                 (Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Bottom := Dest.Top + (Canvas.TextHeight(FloatToStr(Percentage)+ '%'));
     Dest.Right := Dest.Left + (Canvas.TextWidth(FloatToStr(Percentage)+ '%'));
     Bitmap.Width := (Canvas.TextWidth(FloatToStr(Percentage)+ '%'));
     Bitmap.Height := (Canvas.TextHeight(FloatToStr(Percentage)+ '%'));
     Bitmap.Canvas.Font.Color := clWhite;
     Bitmap.Canvas.Font.Size := Height Div 2;
     Bitmap.Canvas.Brush.Color := clBlack;
     Bitmap.Canvas.TextOut((Bitmap.Width Div 2) -
             (Bitmap.Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2),
             (Bitmap.Height Div 2) -
                 (Bitmap.Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2),
                 FloatToStr(Percentage)+ '%');
  End
   Else
  Begin
     Canvas.Font.Size := Width Div 4;
     XPos := (Width Div 2) -
             (Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2);
     YPos := (Height Div 2) -
             (Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Left := (Width Div 2) -
                 (Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Top := (Height Div 2) -
                 (Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2);
     Dest.Bottom := Dest.Top + (Canvas.TextHeight(FloatToStr(Percentage)+ '%'));
     Dest.Right := Dest.Left + (Canvas.TextWidth(FloatToStr(Percentage)+ '%'));
     Bitmap.Width := (Canvas.TextWidth(FloatToStr(Percentage)+ '%'));
     Bitmap.Height := (Canvas.TextHeight(FloatToStr(Percentage)+ '%'));
     Bitmap.Canvas.Font.Color := clWhite;
     Bitmap.Canvas.Font.Size := Width Div 4;
     Bitmap.Canvas.Brush.Color := clBlack;
     Bitmap.Canvas.TextOut((Bitmap.Width Div 2) -
             (Bitmap.Canvas.TextWidth(FloatToStr(Percentage)+ '%') Div 2),
             (Bitmap.Height Div 2) -
                 (Bitmap.Canvas.TextHeight(FloatToStr(Percentage)+ '%') Div 2),
                 FloatToStr(Percentage)+ '%');
  End;
  Src.Left := 0;
  Src.Top := 0;
  Src.Bottom := Bitmap.Height;
  Src.Right := Bitmap.Width;
  Canvas.CopyMode := cmSrcPaint;
  Canvas.CopyRect(Dest,Bitmap.Canvas,Src);
  Bitmap.Free;
End;

Constructor TDataObject.Create(Value : Real; PosLabel : String);
Begin
  FValue := Value;
  FLabel := PosLabel;
End;

Function TwsaGraph.GetLegend(Index : Integer) : String;
Begin
  If FLegend.Count >= Index-1 Then
   Result := FLegend[Index-1];
End;

Procedure TwsaGraph.SetLegend(Index : Integer;Value : String);
Var i : Integer;
Begin
  If (Index-1 <= FLegend.Count) And (FDataList.Count >= Index-1) Then
   Begin
     For i := 0 To (Index-1) - FLegend.Count Do
      FLegend.Add('');
     FLegend[Index-1] := Value;
   End;
End;

Function TwsaGraph.GetNextColor(CurrentColor : Integer) : Integer;
Begin
  Case CurrentColor Of
    clBlack  : Result := clMaroon;
    clMaroon : Result := clGreen;
    clGreen  : Result := clOlive;
    clOlive  : Result := clNavy;
    clNavy   : Result := clPurple;
    clPurple : Result := clTeal;
    clTeal   : Result := clGray;
    clGray   : Result := clSilver;
    clSilver : Result := clRed;
    clRed    : Result := clLime;
    clLime   : Result := clBlue;
    clBlue   : Result := clFuchsia;
    clFuchsia: Result := clAqua;
    clAqua   : Result := clYellow;
//    clWhite  : Result := clYellow;
    clYellow : Result := clBlack;

    else
     Result := clBlack;
  End;
End;

Procedure TwsaGraph.AddData(Series,X : Integer; Value : Real; PosLabel : String);
Var i,Idx : Integer;
Begin
  If FDataList.Count < Series Then
   For i := 0 To Series-FDataList.Count-1 Do
    FDataList.Add(TStringList.Create);
  Idx := TStringList(FDataList[Series-1]).IndexOf(FloatToStr(X));
  If Idx <> - 1 Then
  Begin
    TDataObject(TStringList(FDataList[Series-1]).Objects[Idx]).FValue := Value;
    TDataObject(TStringList(FDataList[Series-1]).Objects[Idx]).FLabel := PosLabel;
  End
  Else
   TStringList(FDataList[Series-1]).AddObject(FloatToStr(X),TDataObject.Create(Value,PosLabel));
  If Value > FMaxValue Then
   FMaxValue := Value;
End;

Procedure TwsaGraph.CalcPeriods;
Var PowerVal : Integer;
Begin
   If FMaxValue > 0 Then
    PowerVal := Round(Power(10,Floor(Log10(FMaxValue))-1))
   Else
    PowerVal := 0;
   If (PowerVal = 0) Then
    Begin
      FIncValue := 1;
      FTicks := 10;
    End
   Else
   If (FMaxValue <= 15 * PowerVal) Then
       Begin
         FIncValue := 1 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 15;
       End
    Else
   If (FMaxValue <= 20 * PowerVal) Then
       Begin
         FIncValue := 2 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 10;
       End
    Else
   If (FMaxValue <= 30 * PowerVal) Then
       Begin
         FIncValue := 3 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 10;
       End
    Else
   If (FMaxValue <= 40 * PowerVal) Then
       Begin
         FIncValue := 5 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 8;
       End
    Else
   If (FMaxValue <= 50 * PowerVal) Then
       Begin
         FIncValue := 5 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 10;
       End
    Else
   If (FMaxValue <= 60 * PowerVal) Then
       Begin
         FIncValue := 5 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 12;
       End
    Else
   If (FMaxValue <= 75 * PowerVal) Then
       Begin
         FIncValue := 5 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 15;
       End
    Else
   If (FMaxValue <= 80 * PowerVal) Then
       Begin
         FIncValue := 5 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 16;
       End
    Else
   If (FMaxValue <= 100 * PowerVal) Then
       Begin
         FIncValue := 10 * Power(10,Floor(Log10(FMaxValue))-1);
         FTicks := 10;
       End;

End;

Constructor TwsaGraph.Create(AOwner : TComponent);
var i : Integer;
    series : Integer;
Begin
  Inherited Create(AOwner);
  LineWidth := 2;
  GraphType := BarGraph;
  PenColor := clRed;
  FLegend := TStringList.Create;
  HeaderFontName := 'MS Sans Serif';
  YAxisFontName := 'MS Sans Serif';
  XAxisFontName := 'MS Sans Serif';
  LeftFontName := 'MS Sans Serif';
  HeaderFontSize := 8;
  FooterFontSize := 8;
  LeftLabel := '';
  Header := '';
  Footer := '';
  YHeader := '';
  XHeader := '';
  FLeftMargin := 10;
  FRightMargin := 10;
  FTopMargin := 10;
  FBottomMargin := 20;
  FMaxValue := 0;
  ShowVertLines := False;
  FDataList := TList.Create;
  BackgroundColor := clWhite;
  Width := 150;
  Height := 100;
  FooterFontColor := clBlue;
  HeaderFontColor := clBlue;
  ShowHorizLines := True;
  XFontSize := 7;
  GraphColor := clGreen;
End;

Destructor TwsaGraph.Destroy;
Var i,j : Integer;
Begin
  Inherited Destroy;
  For i := 0 To FDataList.Count - 1 Do
   Begin
     For j := 0 To TStringList(FDataList[i]).Count -1 Do
      TDataObject(TStringList(FDataList[i]).Objects[j]).Destroy;
     TStringList(FDataList[i]).Destroy;
   End;
  FDataList.Destroy;
  FLegend.Destroy;
End;

Procedure TwsaGraph.ClearGraph;
Var i,j : Integer;
Begin
  For i := 0 To FDataList.Count - 1 Do
   Begin
     For j := 0 To TStringList(FDataList[i]).Count -1 Do
      TDataObject(TStringList(FDataList[i]).Objects[j]).Destroy;
     TStringList(FDataList[i]).Clear;
   End;
  FLeftMargin := 10;
  FRightMargin := 10;
  FTopMargin := 10;
  FBottomMargin := 20;
  FMaxValue := 0;
End;

Procedure TwsaGraph.PlotGraph;
Const CLBlack=clGreen;
Var BarWidth,
    BarHeight : Integer;
    i,j : Integer;
    TickWidth : Real;
    CurrPos : Integer;
    GraphBottomPos, GraphLeftPos : Integer;
    DataValue : Real;
    DataLabel : String;
    GraphHeight : Integer;
    GraphWidth : Integer;
    HighGraphVal : Integer;
    GColor : Integer;
    MaxVals : Integer;
Begin
  Canvas.Brush.Color := BackgroundColor;
  Canvas.Rectangle(0,0,Width,Height);
  //Header
  Canvas.Font.Name := HeaderfontName;
  Canvas.Font.Size := HeaderFontSize;
  Canvas.Font.Color := HeaderFontColor;
  If Header <> '' Then
   FTopMargin := FTopMargin + Canvas.TextHeight(Header) + 10;
  Canvas.TextOut((Width Div 2) - (Canvas.TextWidth(Header) div 2),10,Header);
 If FLegend.Count > 0 Then
   Begin
     Canvas.Font.Color := FPenColor;
     For i := FLegend.Count - 1 DownTo 0 Do
     Begin
       Canvas.Brush.Color := Canvas.Font.Color;
       Canvas.Rectangle(FLeftMargin,Height-(Canvas.TextHeight(FLegend[i])*(i+1))-3,
                        FLeftMargin+20,Height-(Canvas.TextHeight(FLegend[i])*(i+1))+7);
       Canvas.Brush.Color := BackgroundColor;
       Canvas.TextOut(FLeftMargin+22,Height-(Canvas.TextHeight(FLegend[i])*(i+1))-5,FLegend[FLegend.Count-i-1]);
       FBottomMargin := FBottomMargin + Canvas.TextHeight(FLegend[i]);
       Canvas.Font.Color := GetNextColor(Canvas.Font.Color);
     End;
   End;
  //Footer
  Canvas.Font.Name := FooterFontName;
  Canvas.Font.Size := FooterFontSize;
  Canvas.Font.Color := FooterFontColor;
  If Footer <> '' Then
   FBottomMargin := FBottomMargin + Canvas.TextHeight(Footer);
  Canvas.TextOut((Width Div 2) - (Canvas.TextWidth(Footer) div 2),
    Height-FBottomMargin+Canvas.TextHeight(Footer),Footer);
  //Left Label
  Canvas.Font.Name := LeftFontName;
  Canvas.Font.Size := LeftFontSize;
  Canvas.Font.Color := LeftFontColor;
  If LeftLabel <> '' Then
   FLeftMargin := FLeftMargin + Canvas.TextWidth(LeftLabel) + FLeftMargin;
  Canvas.TextOut(10,Height Div 2,LeftLabel);
  CalcPeriods;
  HighGraphVal := Round(FTicks * FIncValue);
  TickWidth := (Height-FTopMargin - FBottomMargin) / FTicks;
  Canvas.Font.Color := YFontColor;
  Canvas.Font.Size := YFontSize;
  Canvas.Font.Name := YAxisFontName;
  FLeftMargin := FLeftMargin + Canvas.TextWidth(FloatToStr(FMaxValue));
  Canvas.Pen.Color := clBlack;
  Canvas.MoveTo(FLeftMargin,Height-FBottomMargin);
  Canvas.LineTo(FLeftMargin,FTopMargin);
  Canvas.MoveTo(FLeftMargin,Height-FBottomMargin);
  Canvas.LineTo(Width-FRightMargin,Height-FBottomMargin);
  GraphBottomPos := Height-FBottomMargin;
  GraphLeftPos := FLeftMargin;
  CurrPos:= GraphBottomPos;
  For i := 1 To FTicks Do
   Begin
     Currpos := Round(GraphBottomPos - (TickWidth * i));
     Canvas.Font.Color := YFontColor;
     Canvas.Font.Size := YFontSize;
     Canvas.TextOut(GraphLeftPos - Canvas.TextWidth(IntToStr(i*Round(FIncValue))) - 2,
                    CurrPos-(Canvas.TextHeight(IntToStr(i*Round(FIncValue))) Div 2),
                    IntToStr(i*Round(FIncValue)));
     Canvas.MoveTo(FLeftMargin-2,CurrPos);
     Canvas.LineTo(FLeftMargin+2,CurrPos);
     If ShowHorizLines Then
      Begin
        Canvas.Pen.Style := psDot;
        Canvas.Pen.Color := clGray;
        Canvas.LineTo(Width-FRightMargin,CurrPos);
        Canvas.Pen.Color := clBlack;
        Canvas.Pen.Style := psSolid;
      End;
   End;
  Canvas.TextOut(GraphLeftPos-Canvas.TextWidth('0')-2,
                 GraphBottomPos-(Canvas.TextHeight('0') DIV 2),'0');
  CurrPos := GraphLeftPos;
  Canvas.Pen.Color := FPenColor;
  GraphHeight := Height-FBottomMargin-FTopMargin;
  GraphWidth := Width - FRightMargin - FLeftMargin;
  Case FGraphType Of
   BarGraph : Begin
                GColor := Canvas.Pen.Color;
                For j := 0 To FDataList.Count - 1 Do
                Begin
                  MaxVals := 0;
                  For i := 0 To FDataList.Count - 1 Do
                   If TStringList(FDataList[i]).Count > MaxVals Then
                    MaxVals := TStringList(FDataList[i]).Count;
                  BarWidth := ((Width-FRightMargin-FLeftMargin) Div MaxVals{TStringList(FDataList[j]).Count});
                  CurrPos := GraphLeftPos;
                  For i := 0 To TStringList(FDataList[j]).Count - 1 Do
                   Begin
                     DataValue := TDataObject(TStringList(FDataList[j]).Objects[i]).FValue;
                     DataLabel := TDataObject(TStringList(FDataList[j]).Objects[i]).FLabel;
                     BarHeight := Floor((DataValue / HighGraphVal) * GraphHeight);
                     Canvas.Brush.Color := GColor;
                     Canvas.Pen.Color := clBlack;
                     Canvas.Rectangle(CurrPos + ((BarWidth Div FDataList.Count)*j),GraphBottomPos - BarHeight,
                                      CurrPos + ((BarWidth Div FDataList.Count)*(j+1)){*(j+2))} {BarWidth},GraphBottomPos);
                     Canvas.Font.Color := XFontColor;
                     Canvas.Font.Name := XFontName;
                     Canvas.Font.Size := XFontSize;
                     Canvas.Brush.Color := BackGroundColor;
                     Canvas.TextOut((BarWidth Div 2)-(Canvas.TextWidth(DataLabel) Div 2)+CurrPos,
                                    GraphBottomPos + 1,DataLabel);
                     CurrPos := CurrPos + BarWidth;
                   End;
                  GColor := GetNextColor(GColor);
                End;
               End;
   LineGraph : Begin
                 For j := 0 To FDataList.Count - 1 Do
                  Begin
                    CurrPos := GraphLeftPos;
                    BarWidth := (Width-FRightMargin-FLeftMargin) Div TStringList(FDataList[j]).Count;
                    //Start level with first pos
                    DataValue := TDataObject(TStringList(FDataList[j]).Objects[0]).FValue;
                    DataLabel := TDataObject(TStringList(FDataList[j]).Objects[0]).FLabel;
                    BarHeight := Floor((DataValue / HighGraphVal) * GraphHeight);
                    Canvas.MoveTo(GraphLeftPos,GraphBottomPos - BarHeight);
                    //
 //                   Canvas.MoveTo(GraphLeftPos,GraphBottomPos);
                    For i := 0 To TStringList(FDataList[j]).Count - 1 Do
                     Begin
                       //-0.123456 is my null marker (skip across null)
                       If TDataObject(TStringList(FDataList[j]).Objects[i]).FValue = -1 Then
                        Continue;
                       DataValue := TDataObject(TStringList(FDataList[j]).Objects[i]).FValue;
                       DataLabel := TDataObject(TStringList(FDataList[j]).Objects[i]).FLabel;
                       BarHeight := Floor((DataValue / HighGraphVal) * GraphHeight);
                       Canvas.Brush.Color := GraphColor;
                       Canvas.Pen.Width := LineWidth;
                       Canvas.LineTo(CurrPos+(BarWidth Div 2),GraphBottomPos - BarHeight);
                       Canvas.Rectangle(CurrPos+(BarWidth Div 2)-2,GraphBottomPos - BarHeight-2,
                                        CurrPos+(BarWidth Div 2)+2,GraphBottomPos - BarHeight+2);
                       Canvas.Brush.Color := BackGroundColor;
                       Canvas.Font.Color := XFontColor;
                       Canvas.Font.Name := XFontName;
                       Canvas.Font.Size := XFontSize;
                       Canvas.TextOut((BarWidth Div 2)-(Canvas.TextWidth(DataLabel) Div 2)+CurrPos,
                                      GraphBottomPos + 1,DataLabel);
                       Canvas.MoveTo(CurrPos+(BarWidth Div 2),GraphBottomPos - BarHeight);
                       CurrPos := CurrPos + BarWidth;
                     End;
                    Canvas.Pen.Color := GetNextColor(Canvas.Pen.Color);
                  End;
               End;
  End;
End;

procedure Register;
begin
  RegisterComponents('Samples', [TwsaGraph]);
end;
end.
